# DocumentTab

A tab with document contents.

**Type:** object

## Properties

- **body** ([Body](body.md)): The main body of the document tab.
- **headers** (object): The headers in the document tab, keyed by header ID.
- **footers** (object): The footers in the document tab, keyed by footer ID.
- **footnotes** (object): The footnotes in the document tab, keyed by footnote ID.
- **documentStyle** ([DocumentStyle](documentstyle.md)): The style of the document tab.
- **suggestedDocumentStyleChanges** (object): The suggested changes to the style of the document tab, keyed by suggestion ID.
- **namedStyles** ([NamedStyles](namedstyles.md)): The named styles of the document tab.
- **suggestedNamedStylesChanges** (object): The suggested changes to the named styles of the document tab, keyed by suggestion ID.
- **lists** (object): The lists in the document tab, keyed by list ID.
- **namedRanges** (object): The named ranges in the document tab, keyed by name.
- **inlineObjects** (object): The inline objects in the document tab, keyed by object ID.
- **positionedObjects** (object): The positioned objects in the document tab, keyed by object ID.
